/*
 * EtherPix simulator
 *
 * Copyright 2017 Stefan Schuermans <stefan schuermans info>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtkmm.h>

#include "config.h"
#include "draw.h"
#include "main_window.h"

/**
 * @brief constructor
 * @param[in] Gtk Window object (a C object)
 * @param[in] builder reference to GTK builder object
 */
MainWindow::MainWindow(BaseObjectType *cobject,
                       const Glib::RefPtr<Gtk::Builder> &builder):
  Gtk::Window(cobject),
  m_builder(builder),
  m_config(NULL)
{
  // get widgets
  builder->get_widget_derived("Draw", m_draw);
  builder->get_widget("Status", m_status);

  // connect callbacks
  signal_hide().connect(sigc::mem_fun(*this, &MainWindow::on_hide));
}

/// virtual destructor
MainWindow::~MainWindow()
{
}

/// set configuration object
void MainWindow::setConfig(Config const &config)
{
  m_config = &config;
  m_draw->setConfig(config);
}

/// window is being hidden
void MainWindow::on_hide()
{
  // leave main loop
  Gtk::Main::quit();
}

/// set status bar text
void MainWindow::set_status(std::string const &txt)
{
  m_status->pop();
  m_status->push(txt);
}

